@@ -540,9 +540,15 @@ AbstractProcessManager::getStringFromAddress(remote_addr_t addr) const
                    << addr;
         Structure<py_unicode_v> unicode(shared_from_this(), addr);
 
-        Python3::_PyUnicode_State state = unicode.getField(&py_unicode_v::o_state);
-        if (state.kind != 1 || state.compact != 1) {
-            throw InvalidRemoteObject();
+        AnyPyUnicodeState state = unicode.getField(&py_unicode_v::o_state);
+        if (versionIsAtLeast(3, 14) and isFreeThreaded()) {
+            if (state.python3_14t.kind != 1 || state.python3_14t.compact != 1) {
+                throw InvalidRemoteObject();
+            }
+        } else {
+            if (state.python3.kind != 1 || state.python3.compact != 1) {
+                throw InvalidRemoteObject();
+            }
         }
 
         len = unicode.getField(&py_unicode_v::o_length);
@@ -706,12 +712,14 @@ AbstractProcessManager::setPythonVersionFromDebugOffsets()
                       << " identify the version as " << parsed;
             setPythonVersion(std::make_pair(parsed.major, parsed.minor));
             Structure<py_runtime_v> py_runtime(shared_from_this(), pyruntime_addr);
+            bool is_free_threaded = py_runtime.getField(&py_runtime_v::o_dbg_off_free_threaded);
             std::unique_ptr<python_v> offsets = loadDebugOffsets(py_runtime);
             if (offsets) {
                 LOG(INFO) << "_Py_DebugOffsets appear to be valid and will be used";
                 warnIfOffsetsAreMismatched(pyruntime_addr);
                 d_debug_offsets_addr = pyruntime_addr;
                 d_debug_offsets = std::move(offsets);
+                d_is_free_threaded = is_free_threaded;
                 return;
             }
         }
@@ -750,6 +758,23 @@ AbstractProcessManager::findPythonVersion() const
     }
     int major = (version >> 24) & 0xFF;
     int minor = (version >> 16) & 0xFF;
+    int level = (version >> 4) & 0x0F;
+
+    if (major == 0 && minor == 0) {
+        LOG(DEBUG) << "Failed to determine Python version from symbols: empty data copied";
+        return {-1, -1};
+    }
+
+    if (major != 2 && major != 3) {
+        LOG(DEBUG) << "Failed to determine Python version from symbols: invalid major version";
+        return {-1, -1};
+    }
+
+    if (level != 0xA && level != 0xB && level != 0xC && level != 0xF) {
+        LOG(DEBUG) << "Failed to determine Python version from symbols: invalid release level";
+        return {-1, -1};
+    }
+
     LOG(DEBUG) << "Python version determined from symbols: " << major << "." << minor;
     return {major, minor};
 }
@@ -1262,6 +1287,12 @@ AbstractProcessManager::versionIsAtLeast(int required_major, int required_minor)
     return d_major > required_major || (d_major == required_major && d_minor >= required_minor);
 }
 
+bool
+AbstractProcessManager::isFreeThreaded() const
+{
+    return d_is_free_threaded;
+}
+
 const python_v&
 AbstractProcessManager::offsets() const
 {
